aboutsummaryrefslogtreecommitdiffstats
path: root/sound/isa/sgalaxy.c
diff options
context:
space:
mode:
authorTakashi Iwai <tiwai@suse.de>2005-11-17 14:42:36 +0100
committerJaroslav Kysela <perex@suse.cz>2006-01-03 12:18:39 +0100
commit11ff5c62b1327cc7bdcfcf66b4b718495fea0043 (patch)
treea6ed8733002ac196993a091504d804dca48317a1 /sound/isa/sgalaxy.c
parent[ALSA] Remove xxx_t typedefs: ISA SoundScape (diff)
downloadlinux-dev-11ff5c62b1327cc7bdcfcf66b4b718495fea0043.tar.xz
linux-dev-11ff5c62b1327cc7bdcfcf66b4b718495fea0043.zip
[ALSA] Remove xxx_t typedefs: ISA SB/AD-clone
Modules: ALS100 driver,AZT2320 driver,DT019x driver,Sound Galaxy driver Remove xxx_t typedefs from the ISA SB/AD-clone drivers (als100, azt2320, dt019x, sgalaxy). Signed-off-by: Takashi Iwai <tiwai@suse.de>
Diffstat (limited to '')
-rw-r--r--sound/isa/sgalaxy.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/sound/isa/sgalaxy.c b/sound/isa/sgalaxy.c
index 52f2294da62b..c16b53ba7ea6 100644
--- a/sound/isa/sgalaxy.c
+++ b/sound/isa/sgalaxy.c
@@ -65,7 +65,7 @@ MODULE_PARM_DESC(dma1, "DMA1 # for Sound Galaxy driver.");
#define SGALAXY_AUXC_LEFT 18
#define SGALAXY_AUXC_RIGHT 19
-static snd_card_t *snd_sgalaxy_cards[SNDRV_CARDS] = SNDRV_DEFAULT_PTR;
+static struct snd_card *snd_sgalaxy_cards[SNDRV_CARDS] = SNDRV_DEFAULT_PTR;
#define PFX "sgalaxy: "
@@ -75,7 +75,7 @@ static snd_card_t *snd_sgalaxy_cards[SNDRV_CARDS] = SNDRV_DEFAULT_PTR;
#define AD1848P1( port, x ) ( port + c_d_c_AD1848##x )
/* from lowlevel/sb/sb.c - to avoid having to allocate a sb_t for the */
/* short time we actually need it.. */
static int snd_sgalaxy_sbdsp_reset(unsigned long port)
@@ -180,10 +180,10 @@ AD1848_DOUBLE("Aux Playback Switch", 0, SGALAXY_AUXC_LEFT, SGALAXY_AUXC_RIGHT, 7
AD1848_DOUBLE("Aux Playback Volume", 0, SGALAXY_AUXC_LEFT, SGALAXY_AUXC_RIGHT, 0, 0, 31, 0)
};
-static int __init snd_sgalaxy_mixer(ad1848_t *chip)
+static int __init snd_sgalaxy_mixer(struct snd_ad1848 *chip)
{
- snd_card_t *card = chip->card;
- snd_ctl_elem_id_t id1, id2;
+ struct snd_card *card = chip->card;
+ struct snd_ctl_elem_id id1, id2;
unsigned int idx;
int err;
@@ -221,8 +221,8 @@ static int __init snd_sgalaxy_probe(int dev)
static int possible_irqs[] = {7, 9, 10, 11, -1};
static int possible_dmas[] = {1, 3, 0, -1};
int err, xirq, xdma1;
- snd_card_t *card;
- ad1848_t *chip;
+ struct snd_card *card;
+ struct snd_ad1848 *chip;
if (sbport[dev] == SNDRV_AUTO_PORT) {
snd_printk(KERN_ERR PFX "specify SB port\n");
@@ -75,7 +75,7 @@ static snd_card_t *snd_sgalaxy_cards[SNDRV_CARDS] = SNDRV_DEFAULT_PTR;
#define AD1848P1( port, x ) ( port + c_d_c_AD1848##x )
-/* from lowlevel/sb/sb.c - to avoid having to allocate a sb_t for the */
+/* from lowlevel/sb/sb.c - to avoid having to allocate a struct snd_sb for the */
/* short time we actually need it.. */
static int snd_sgalaxy_sbdsp_reset(unsigned long port)